@@ -51,6 +51,8 @@ parser.add_argument("--no-colors", dest="no_colors", action="store_true",
                     help="disable terminal color highlighting", default=False)
 parser.add_argument("--show-skipped", dest="show_skipped", action="store_true",
                     help="show skipped tests, default: False", default=False)
+parser.add_argument("--trim", dest="trim", action="store_true",
+                    help="show trimmed result messages, default: False", default=False)
 parser.add_argument("-v", "--version", action="version", version=f"{__version__}")
 parser.add_argument("--license", action="version", help="show program's license and exit", version=f"{__license__}")
 
@@ -63,6 +65,5 @@ requirement_handler.add_command(commands)
 document_handler.add_command(commands)
 show_handler.add_command(commands)
 
-if database_handler: 
+if database_handler:
     database_handler.add_command(commands)
-
