@@ -19,6 +19,7 @@ from .utils.enum import IntEnum
 from .exceptions import SpecificationError, RequirementError, ResultException
 from .baseobject import TestObject, Table
 from .baseobject import get, hash
+from .testtype import TestType
 import testflows._core.contrib.rsa as rsa
 
 class Result(TestObject, ResultException):
@@ -526,6 +527,48 @@ class Skips(NamedList):
     def __init__(self, *items):
         super(Skips, self).__init__(*items)
 
+class _FilterTags(NamedValue):
+    """filter tags object.
+    """
+    def __init__(self, test=None, suite=None, module=None, any=None):
+        test = set(test) if test is not None else set()
+        suite = set(suite) if suite is not None else set()
+        module = set(module) if module is not None else set()
+        any = set(any) if any is not None else set()
+        if any:
+            test = test.union(any)
+            suite = suite.union(any)
+            module = module.union(any)
+        super(_FilterTags, self).__init__({TestType.Test: test, TestType.Suite: suite, TestType.Module: module})
+
+class OnlyTags(_FilterTags):
+    """only_tags filter object.
+
+    ```python
+    @OnlyTags(
+       test=[tagA,(tagA,tagB),...],
+       suite=[...],
+       module=[...],
+       any=[...]
+    )
+    ```
+    """
+    name = "only_tags"
+
+class SkipTags(_FilterTags):
+    """skip_tags filter object.
+
+    ```python
+    @SkipTags(
+       test=[tagA,(tagA,tagB),...],
+       suite=[...],
+       module=[...],
+       any=[...]
+    )
+    ```
+    """
+    name = "skip_tags"
+
 class Setup(NamedValue):
     name = "setup"
 
@@ -567,7 +610,7 @@ class FFails(NamedValue):
 
     def __init__(self, value):
         value = dict(value)
-        value = {p: FFail(*v).value for p, v in value.items()}
+        value = {p: list(FFail(*v).value.values())[0] for p, v in value.items()}
         super(FFails, self).__init__(value)
 
     def items(self):
@@ -589,13 +632,9 @@ class FFails(NamedValue):
 class FFail(NamedValue):
     """ffails (forced fails) container with single result.
     """
-    result = None
     name = "ffails"
 
-    def __init__(self, reason, pattern="", when=None, result=None):
-        if result is not None:
-            self.result = result
-        
+    def __init__(self, result, reason, when=None, pattern=""):
         if not issubclass(result, Result):
             raise TypeError(f"invalid result '{result}' type")
         if not type(reason) in (str,):
@@ -603,37 +642,43 @@ class FFail(NamedValue):
         if when is not None and not callable(when):
             raise TypeError(f"when '{type(when)}' must be callable")
         
-        super(FFail, self).__init__({pattern: (self.result, reason, when)})
+        super(FFail, self).__init__({pattern: (result, reason, when)})
 
 class Skipped(FFail):
     """ffails (forced fails) container with single Skip result.
     """
-    result = Skip
+    def __init__(self, reason, when=None, pattern=""):
+        super(Skipped, self).__init__(reason=reason, when=when, pattern=pattern, result=Skip)
 
 class Failed(FFail):
     """ffails (forced fails) container with single Fail result.
     """
-    result = Fail
+    def __init__(self, reason, when=None, pattern=""):
+        super(Failed, self).__init__(reason=reason, when=when, pattern=pattern, result=Fail)
 
 class XFailed(FFail):
     """ffails (forced fails) container with single XFail result.
     """
-    result = XFail
+    def __init__(self, reason, when=None, pattern=""):
+        super(XFailed, self).__init__(reason=reason, when=when, pattern=pattern, result=XFail)
 
 class XErrored(FFail):
     """ffails (forced fails) container with single XError result.
     """
-    result = XError
+    def __init__(self, reason, when=None, pattern=""):
+        super(XErrored, self).__init__(reason=reason, when=when, pattern=pattern, result=XError)
 
 class Okayed(FFail):
     """ffails (forced fails) container with single OK result.
     """
-    result = OK
+    def __init__(self, reason, when=None, pattern=""):
+        super(Okayed, self).__init__(reason=reason, when=when, pattern=pattern, result=OK)
 
 class XOkayed(FFail):
     """ffails (forced fails) container with single XOK result.
     """
-    result = XOK
+    def __init__(self, reason, when=None, pattern=""):
+        super(XOkayed, self).__init__(reason=reason, when=when, pattern=pattern, result=XOK)
 
 class XFlags(NamedValue):
     """xflags container.
@@ -679,7 +724,7 @@ class Repeat(NamedValue):
     """
     name = "repeats"
 
-    def __init__(self, count, pattern="", until="complete"):
+    def __init__(self, count, until="complete", pattern=""):
         self.count = int(count)
         self.pattern = str(pattern)
         self.until = str(until)
@@ -703,7 +748,7 @@ class Retries(NamedValue):
 
     def __init__(self, value):
         value = dict(value)
-        value = {p: Retry(*r).value for p, r in value.items()}
+        value = {p: list(Retry(*r).value.values())[0] for p, r in value.items()}
         super(Retries, self).__init__(value)
 
 class Retry(NamedValue):
